@@ -13,7 +13,7 @@ from urllib3.util.retry import Retry
 import aleph_alpha_client
 from aleph_alpha_client.document import Document
 from aleph_alpha_client.explanation import ExplanationRequest, ExplanationResponse
-from aleph_alpha_client.image import ImagePrompt
+from aleph_alpha_client.image import Image
 from aleph_alpha_client.prompt import _to_prompt_item, _to_serializable_prompt
 from aleph_alpha_client.summarization import SummarizationRequest, SummarizationResponse
 from aleph_alpha_client.qa import QaRequest, QaResponse
@@ -88,6 +88,13 @@ class AlephAlphaClient:
         request_timeout_seconds (int, optional, default 305):
             Client timeout that will be set for HTTP requests in the `requests` library's API calls.
             Server will close all requests after 300 seconds with an internal server error.
+
+        total_retries(int, optional, default 8)
+            The number of retries made in case requests fail with certain retryable status codes. If the last
+            retry fails a corresponding exception is raised. Note, that between retries an exponential backoff
+            is applied, starting with 0.5 s after the first retry and doubling for each retry made. So with the
+            default setting of 8 retries a total wait time of 63.5 s is added between the retries.
+
     """
 
     def __init__(
@@ -97,6 +104,7 @@ class AlephAlphaClient:
         email=None,
         password=None,
         request_timeout_seconds=DEFAULT_REQUEST_TIMEOUT,
+        total_retries: int = 8,
     ):
         warnings.warn(
             "AlephAlphaClient is deprecated and will be removed in the next major release. Use Client or AsyncClient instead.",
@@ -111,7 +119,7 @@ class AlephAlphaClient:
         self.request_timeout_seconds = request_timeout_seconds
 
         retry_strategy = Retry(
-            total=8,
+            total=total_retries,
             backoff_factor=0.25,
             status_forcelist=RETRY_STATUS_CODES,
             allowed_methods=["POST", "GET"],
@@ -225,7 +233,7 @@ class AlephAlphaClient:
     def complete(
         self,
         model: str,
-        prompt: Union[str, List[Union[str, ImagePrompt]]] = "",
+        prompt: Union[str, List[Union[str, Image]]] = "",
         hosting: Optional[str] = None,
         maximum_tokens: Optional[int] = 64,
         temperature: Optional[float] = 0.0,
@@ -251,6 +259,10 @@ class AlephAlphaClient:
         sequence_penalty: float = 0.0,
         sequence_penalty_min_length: int = 2,
         use_multiplicative_sequence_penalty: bool = False,
+        completion_bias_inclusion: Optional[Sequence[str]] = None,
+        completion_bias_inclusion_first_token_only: bool = False,
+        completion_bias_exclusion: Optional[Sequence[str]] = None,
+        completion_bias_exclusion_first_token_only: bool = False,
     ):
         """Generates samples from a prompt.
 
@@ -377,6 +389,20 @@ class AlephAlphaClient:
 
             use_multiplicative_sequence_penalty (bool, default False)
                 Flag deciding whether sequence penalty is applied multiplicatively (True) or additively (False).
+
+            completion_bias_inclusion (List[str], default [])
+                Bias the completion to only generate options within this list;
+                all other tokens are disregarded at sampling
+
+            completion_bias_inclusion_first_token_only (bool, default False)
+                Only consider the first token for the completion_bias_inclusion
+
+            completion_bias_exclusion (List[str], default [])
+                Bias the completion to NOT generate options within this list;
+                all other tokens are unaffected in sampling
+
+            completion_bias_exclusion_first_token_only (bool, default False)
+                Only consider the first token for the completion_bias_exclusion
         """
 
         payload = {
@@ -406,6 +432,10 @@ class AlephAlphaClient:
             "sequence_penalty": sequence_penalty,
             "sequence_penalty_min_length": sequence_penalty_min_length,
             "use_multiplicative_sequence_penalty": use_multiplicative_sequence_penalty,
+            "completion_bias_inclusion": completion_bias_inclusion,
+            "completion_bias_inclusion_first_token_only": completion_bias_inclusion_first_token_only,
+            "completion_bias_exclusion": completion_bias_exclusion,
+            "completion_bias_exclusion_first_token_only": completion_bias_exclusion_first_token_only,
         }
 
         if hosting is not None:
@@ -428,7 +458,7 @@ class AlephAlphaClient:
     def embed(
         self,
         model: str,
-        prompt: Union[str, Sequence[Union[str, ImagePrompt]]],
+        prompt: Union[str, Sequence[Union[str, Image]]],
         pooling: List[str],
         layers: List[int],
         hosting: Optional[str] = None,
@@ -541,9 +571,7 @@ class AlephAlphaClient:
                 Return normalized embeddings. This can be used to save on additional compute when applying a cosine similarity metric.
         """
 
-        serializable_prompt = _to_serializable_prompt(
-            prompt=request.prompt.items, at_least_one_token=True
-        )
+        serializable_prompt = request.prompt.to_json()
 
         payload: Dict[str, Any] = {
             "model": model,
@@ -569,7 +597,7 @@ class AlephAlphaClient:
         model: str,
         completion_expected,
         hosting: Optional[str] = None,
-        prompt: Union[str, List[Union[str, ImagePrompt]]] = "",
+        prompt: Union[str, List[Union[str, Image]]] = "",
     ):
         """
         Evaluates the model's likelihood to produce a completion given a prompt.
