@@ -7,7 +7,7 @@ from typing import (
     Optional,
     Tuple,
 )
-from aleph_alpha_client.prompt import Prompt, _to_serializable_prompt
+from aleph_alpha_client.prompt import Prompt
 
 
 class EmbeddingRequest(NamedTuple):
@@ -60,7 +60,7 @@ class EmbeddingRequest(NamedTuple):
 
     def to_json(self) -> Dict[str, Any]:
         payload = self._asdict()
-        payload["prompt"] = _to_serializable_prompt(self.prompt.items)
+        payload["prompt"] = self.prompt.to_json()
         return payload
 
 
@@ -155,7 +155,7 @@ class SemanticEmbeddingRequest(NamedTuple):
     def to_json(self) -> Dict[str, Any]:
         payload = self._asdict()
         payload["representation"] = self.representation.value
-        payload["prompt"] = _to_serializable_prompt(self.prompt.items)
+        payload["prompt"] = self.prompt.to_json()
         return payload
 
 
